@@ -301,7 +301,7 @@ rotation).  Use --follow=name in that case.  That causes tail to track the\n\
 named file by reopening it periodically to see if it has been removed and\n\
 recreated by some other program.\n\
 "), stdout);
-      puts (_("\nReport bugs to <bug-textutils@gnu.org>."));
+      printf (_("\nReport bugs to <%s>.\n"), PACKAGE_BUGREPORT);
     }
   exit (status == 0 ? EXIT_SUCCESS : EXIT_FAILURE);
 }
@@ -962,7 +962,8 @@ tail_forever (struct File_spec *f, int nfiles)
 	  if (stats.st_size == f[i].size)
 	    {
 	      f[i].n_consecutive_size_changes = 0;
-	      if (++f[i].n_unchanged_stats > max_n_unchanged_stats_between_opens
+	      if ((max_n_unchanged_stats_between_opens
+		   <= f[i].n_unchanged_stats++)
 		  && follow_mode == Follow_name)
 		{
 		  recheck (&f[i]);
@@ -971,14 +972,11 @@ tail_forever (struct File_spec *f, int nfiles)
 	      continue;
 	    }
 
-	  /* Size changed.  */
-	  ++f[i].n_consecutive_size_changes;
-
 	  /* Ensure that a file that's unlinked or moved aside, yet always
 	     growing will be recognized as having been renamed.  */
-	  if (follow_mode == Follow_name
-	      && (f[i].n_consecutive_size_changes
-		  > max_n_consecutive_size_changes_between_opens))
+	  if ((max_n_consecutive_size_changes_between_opens
+	       <= f[i].n_consecutive_size_changes++)
+	      && follow_mode == Follow_name)
 	    {
 	      f[i].n_consecutive_size_changes = 0;
 	      recheck (&f[i]);
@@ -1360,13 +1358,13 @@ parse_obsolescent_option (int argc, const char *const *argv,
   else
     {
       strtol_error s_err;
-      unsigned long int tmp_ulong;
+      uintmax_t tmp;
       char *end;
 
-      s_err = xstrtoul (n_string, &end, 10, &tmp_ulong,
-			*n_string_end == 'b' ? "b" : NULL);
-      if (s_err == LONGINT_OK && tmp_ulong <= OFF_T_MAX)
-	*n_units = (off_t) tmp_ulong;
+      s_err = xstrtoumax (n_string, &end, 10, &tmp,
+			  *n_string_end == 'b' ? "b" : NULL);
+      if (s_err == LONGINT_OK && tmp <= OFF_T_MAX)
+	*n_units = (off_t) tmp;
       else
 	{
 	  /* Extract a NUL-terminated string for the error message.  */
